@@ -176,6 +176,14 @@ impl OptimizationContext {
         result.cache.max_single_tensor_numel = settings.max_single_tensor_memory / dtype.size();
         result
     }
+
+    pub fn stringify_logs(&self) -> String {
+        format!(
+            "let slow_einsums = {}; let simplifications= {};",
+            self.cache.slow_einsum_log.repr(),
+            self.cache.simplification_log.repr()
+        )
+    }
 }
 
 #[pyfunction]
@@ -240,9 +248,6 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
         println!("Final Circuit");
         circuit.compiler_print();
     }
-    if context.settings.log_slow_einsums {
-        println!("{}", context.cache.slow_einsum_log.repr());
-    }
     circuit
 }
 
