@@ -663,6 +663,18 @@ impl Rearrange {
         )
         .unwrap()
     }
+
+    pub fn nrc_elim_identity(
+        node: CircuitRc,
+        spec: RearrangeSpec,
+        name: Option<String>,
+    ) -> CircuitRc {
+        if spec.is_identity() {
+            node
+        } else {
+            Rearrange::nrc(node, spec, name)
+        }
+    }
 }
 
 circuit_node_extra_impl!(Rearrange);
