@@ -67,7 +67,7 @@ use self::{
     print::{print_circuit_stats, repr_circuit_deep_compiler},
 };
 
-pub type NamedAxes = Vec<Option<String>>;
+pub type NamedAxes = Option<Vec<Option<String>>>;
 pub trait CircuitNode: CircuitNodePrivate {
     // ==== implementable section ===
     //
@@ -142,16 +142,26 @@ pub trait CircuitNode: CircuitNodePrivate {
     }
 
     fn compute_named_axes(&self) -> NamedAxes {
+        if !self.children().any(|x| x.info().named_axes.is_some()) {
+            return None;
+        }
         let child_axis_map = self.child_axis_map();
         let mut result: Vec<Option<String>> = vec![None; self.info().rank()];
+        let mut did_anything = false;
         for (mp, child) in zip(child_axis_map, self.children()) {
-            for (out_axis, name) in zip(mp, &child.info().named_axes) {
-                if let Some(out_axis)=out_axis && let Some(name)=name{
+            if let Some(child_names) = &child.info().named_axes {
+                for (out_axis, name) in zip(mp, child_names) {
+                    if let Some(out_axis)=out_axis && let Some(name)=name{
                     result[out_axis]=Some(name.clone());
+                    did_anything=true;
+                }
                 }
             }
         }
-        result
+        if !did_anything {
+            return None;
+        }
+        Some(result)
     }
 
     fn map_children<'a, F, E>(&'a self, mut f: F) -> Result<Self, CircuitConstructionError>
@@ -229,30 +239,22 @@ pub trait CircuitNode: CircuitNodePrivate {
         self.info_mut().shape = shape.clone(); // set shape so methods to compute other info can use it
 
         let mut hasher = self.compute_hash();
-        let named_axes = if self
-            .children()
-            .any(|x| !x.info().named_axes.iter().all(|x| x.is_none()))
-        {
-            self.compute_named_axes()
-        } else {
-            vec![None; shape.len()]
-        };
+        let named_axes = self.compute_named_axes();
         hasher.update(self.name().unwrap_or("").as_bytes());
         hasher.update(&self.node_type_uuid());
         hasher.update(uuid!("025e9af4-1366-4211-aa5f-7c28fc6cdf9f").as_bytes());
-        for axis in &named_axes {
-            hasher.update(axis.as_ref().unwrap_or(&"".to_owned()).as_bytes());
+        if let Some(named_axes_real) = &named_axes {
+            for axis in named_axes_real {
+                hasher.update(axis.as_ref().unwrap_or(&"".to_owned()).as_bytes());
+            }
         }
-        *self.info_mut() = CachedCircuitInfo {
-            shape,
-            is_constant: self.compute_is_constant(),
-            is_explicitly_computable: self.compute_is_explicitly_computable(),
-            can_be_sampled: self.compute_can_be_sampled(),
-            hash: hasher.finalize().into(),
-            max_non_input_size: self.max_non_input_size(),
-            device_dtype: self.compute_device_dtype()?,
-            named_axes,
-        };
+        self.info_mut().is_constant = self.compute_is_constant();
+        self.info_mut().is_explicitly_computable = self.compute_is_explicitly_computable();
+        self.info_mut().can_be_sampled = self.compute_can_be_sampled();
+        self.info_mut().hash = hasher.finalize().into();
+        self.info_mut().max_non_input_size = self.max_non_input_size();
+        self.info_mut().device_dtype = self.compute_device_dtype()?;
+        self.info_mut().named_axes = named_axes;
         Ok(self)
     }
 
