@@ -58,11 +58,11 @@ pub fn repr_circuit_deep_compiler(circuit: &Circuit) -> String {
                 _ => "".to_owned(),
             }
         });
-        if circ.info().named_axes.iter().any(|x| x.is_some()) {
+        if let Some(real_named_axes)= &circ.info().named_axes && real_named_axes.iter().any(|x| x.is_some()) {
             result.push_str(&format!(
                 " NA[{}]",
                 circ.info()
-                    .named_axes
+                    .named_axes.as_ref().unwrap()
                     .iter()
                     .map(|x| match x {
                         None => "".to_owned(),
