@@ -41,6 +41,11 @@ impl RustRepr for String {
         format!("\"{}\".to_owned()", self)
     }
 }
+impl RustRepr for &str {
+    fn repr(&self) -> String {
+        format!("\"{}\"", self)
+    }
+}
 impl RustRepr for Uuid {
     fn repr(&self) -> String {
         format!("uuid!(\"{}\")", self)
