@@ -3,6 +3,11 @@
 // Personally, I like or_fun_call as a lint. But currently code fails...
 #![allow(clippy::too_many_arguments, clippy::or_fun_call)]
 
+use mimalloc::MiMalloc;
+
+#[global_allocator]
+static GLOBAL: MiMalloc = MiMalloc;
+
 /// reexport
 pub use pyo3;
 pub use uuid;
